pub struct Color(pub [f64; 3]);Expand description
A PDF color ([R, G, B]).
Rendering clips components to 0.0..=1.0, including infinities. NaN is
rendered as 0.0. Values already in range, including signed zero, are kept.
Tuple Fields
0: [f64; 3]Trait Implementations
impl Copy for Color
Sourceimpl PartialOrd for Color
impl PartialOrd for Color
Sourceimpl Pixel for Color
impl Pixel for Color
Sourcetype Canvas = Canvas
type Canvas = Canvas
The type that stores an intermediate buffer before finalizing to a
concrete image
Sourcefn default_color(color: ModuleColor) -> Self
fn default_color(color: ModuleColor) -> Self
Obtains the default pixel color when a module is dark or light.
Sourcefn default_unit_size() -> (u32, u32)
fn default_unit_size() -> (u32, u32)
Obtains the default module size. The result must be at least 1×1.
impl StructuralPartialEq for Color